thorlabs_apt_device
===================

A python interface to ThorLabs devices which communicate using the APT protocol.

Currently supports DC motor driven devices such as translation stages, however it should be
straightforward to implement extension classes to support other devices.


Support
-------

Documentation can be found online at `<https://thorlabs-apt-device.readthedocs.io/en/latest/>`_.

Bug reports, feature requests and suggestions can be submitted to the `issue tracker <https://gitlab.com/ptapping/thorlabs-apt-device/-/issues>`_.


License
-------

All original work is free and open source, licensed under the GNU Public License.
See the `LICENSE.txt <https://gitlab.com/ptapping/thorlabs-apt-device/-/blob/main/LICENSE.txt>`_ for details.

A fork of the `thorlabs-apt-protocol <https://gitlab.com/yaq/thorlabs-apt-protocol>`_ library is
included under the ``protocol`` directory, which remains under an MIT license.
See `LICENSE <https://gitlab.com/ptapping/thorlabs-apt-device/protocol/-/blob/main/LICENSE>`_ for details.